[![ftmq-search on pypi](https://img.shields.io/pypi/v/ftmq-search)](https://pypi.org/project/ftmq-search/) [![Python test and package](https://github.com/investigativedata/ftmq-search/actions/workflows/python.yml/badge.svg)](https://github.com/investigativedata/ftmq-search/actions/workflows/python.yml) [![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit) [![Coverage Status](https://coveralls.io/repos/github/investigativedata/ftmq-search/badge.svg?branch=main)](https://coveralls.io/github/investigativedata/ftmq-search?branch=main) [![MIT License](https://img.shields.io/pypi/l/ftmq-search)](./LICENSE)

# ftmq-search

Search stores logic for ftmq
